@@ -1,8 +1,8 @@
-__version__ = "0.41.4"
+__version__ = "0.42.3"
 __version_info__ = tuple(__version__.split("."))
 
 
 from . import context, di  # noqa: F401
 from .components import ComponentLookupError, Components  # noqa: F401
 from .config import ConfigSource  # noqa: F401
-from .plugin import Cancel, Teardown, run  # noqa: F401
+from .plugin import Cancel, Teardown, run, stage
